use strict;
use warnings FATAL => 'all';

use HTML::Zoom;
use Test::More tests => 12;

ok my $zoom = HTML::Zoom->from_html(<<HTML);
<html>
  <head>
    <title>Hi!</title>
  </head>
  <body id="content-area">
    <h1>Test</h1>
    <div>
      <p class="first-para">Some stuff</p>
      <p class="boday-para">More stuff</p>
    </div>
    <p id="footer">Copryright 2222</p>
  </body>
</html>
HTML

ok my $fh = $zoom->to_fh,
  'got filehandle';

ok my $html = $zoom->to_html,
  'got html';

ok my $lines = join('', $zoom->to_fh->getlines),
  'got joined lines';

is $html, $lines,
  'straight html is same as lines';

{
  $fh->read(my $buff, 2);

  ok $buff,
    'got a populated buffer';

  is $buff, '<h',
    'got expected info in buffer';
}

{
  $fh->read(my $buff, 4);

  ok $buff,
    'got a populated buffer';

  is $buff, 'tml>',
    'got expected info in buffer';
}

{
  ##$fh->read(my $buff, 6, 20);
  $fh->read(my $buff, 6, 14);

  ok $buff,
    'got a populated buffer';

  is $buff, '<title',
    'got expected info in buffer';
}

{
  my @lines;
  while($fh->read(my $buff, 15)) {
    push @lines, $buff;
  }

  is $#lines, 15,
    'correct number of lines';
}


print (stat $fh);
